from app import app
from pyrogram import filters
from pyrogram.types import Message, InlineKeyboardMarkup, InlineKeyboardButton, ForceReply, ReplyKeyboardMarkup, ReplyKeyboardRemove
from pyrogram.client import Client
from classes.holo_user import HoloUser, UserInvalidError, UserNotFoundError
from modules.utils import locale, all_locales
from modules.database import col_spoilers
from modules import custom_filters

# Any other input ==============================================================================================================
@app.on_message(custom_filters.member & ~filters.scheduled & filters.private & filters.text)
async def handler_spoiler_text(app: Client, msg: Message):

    try:
        holo_user = HoloUser(msg.from_user)
    except (UserInvalidError, UserNotFoundError):
        return

    if holo_user.application_state()[0] != "fill" and holo_user.sponsorship_state()[0] != "fill":

        spoiler = col_spoilers.find_one( {"user": msg.from_user.id, "completed": False} )

        if spoiler is None:
            return

        if spoiler["photo"] is None and spoiler["video"] is None and spoiler["animation"] is None and spoiler["text"] is None:
            col_spoilers.find_one_and_update( {"user": msg.from_user.id, "completed": False}, {"$set": {"text": msg.text}} )
            await msg.reply_text(locale("spoiler_send_description", "message", locale=msg.from_user), reply_markup=ReplyKeyboardMarkup(locale("spoiler_description", "keyboard"), resize_keyboard=True, one_time_keyboard=True, placeholder=locale("spoiler_description", "force_reply", locale=msg.from_user)))
        else:
            for lc in all_locales("spoiler_description", "keyboard"):
                if msg.text == lc[-1][0]:
                    await msg.reply_text(locale("spoiler_description_enter", "message", locale=msg.from_user), reply_markup=ForceReply(placeholder=locale("spoiler_description", "force_reply", locale=msg.from_user)))
                    return
            if msg.text != "-":
                col_spoilers.find_one_and_update( {"user": msg.from_user.id, "completed": False}, {"$set": {"description": msg.text, "completed": True}} )
            await msg.reply_text(locale("spoiler_using_description", "message", locale=msg.from_user).format(msg.text), reply_markup=ReplyKeyboardRemove())
            await msg.reply_text(locale("spoiler_ready", "message", locale=msg.from_user), quote=False, reply_markup=InlineKeyboardMarkup([[InlineKeyboardButton(locale("spoiler_send", "button", locale=msg.from_user), switch_inline_query=f"spoiler:{spoiler['_id'].__str__()}")]]))

@app.on_message(custom_filters.member & ~filters.scheduled & filters.private & filters.photo)
async def handler_spoiler_photo(app: Client, msg: Message):

    try:
        holo_user = HoloUser(msg.from_user)
    except (UserInvalidError, UserNotFoundError):
        return

    if holo_user.application_state()[0] != "fill" and holo_user.sponsorship_state()[0] != "fill":
    

        if col_spoilers.find_one( {"user": msg.from_user.id, "completed": False} ) is None:
            return

        col_spoilers.find_one_and_update( {"user": msg.from_user.id, "completed": False}, {"$set": {"photo": msg.photo.file_id}} )
        await msg.reply_text(locale("spoiler_send_description", "message", locale=msg.from_user), reply_markup=ReplyKeyboardMarkup(locale("spoiler_description", "keyboard"), resize_keyboard=True, one_time_keyboard=True, placeholder=locale("spoiler_description", "force_reply", locale=msg.from_user)))

@app.on_message(custom_filters.member & ~filters.scheduled & filters.private & filters.video)
async def handler_spoiler_video(app: Client, msg: Message):

    try:
        holo_user = HoloUser(msg.from_user)
    except (UserInvalidError, UserNotFoundError):
        return

    if holo_user.application_state()[0] != "fill" and holo_user.sponsorship_state()[0] != "fill":

        if col_spoilers.find_one( {"user": msg.from_user.id, "completed": False} ) is None:
            return

        col_spoilers.find_one_and_update( {"user": msg.from_user.id, "completed": False}, {"$set": {"video": msg.video.file_id}} )
        await msg.reply_text(locale("spoiler_send_description", "message", locale=msg.from_user), reply_markup=ReplyKeyboardMarkup(locale("spoiler_description", "keyboard"), resize_keyboard=True, one_time_keyboard=True, placeholder=locale("spoiler_description", "force_reply", locale=msg.from_user)))

@app.on_message(custom_filters.member & ~filters.scheduled & filters.private & filters.animation)
async def handler_spoiler_animation(app: Client, msg: Message):

    try:
        holo_user = HoloUser(msg.from_user)
    except (UserInvalidError, UserNotFoundError):
        return

    if holo_user.application_state()[0] != "fill" and holo_user.sponsorship_state()[0] != "fill":

        if col_spoilers.find_one( {"user": msg.from_user.id, "completed": False} ) is None:
            return

        col_spoilers.find_one_and_update( {"user": msg.from_user.id, "completed": False}, {"$set": {"animation": msg.animation.file_id}} )
        await msg.reply_text(locale("spoiler_send_description", "message", locale=msg.from_user), reply_markup=ReplyKeyboardMarkup(locale("spoiler_description", "keyboard"), resize_keyboard=True, one_time_keyboard=True, placeholder=locale("spoiler_description", "force_reply", locale=msg.from_user)))